/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Written by Richard Stallman by simplifying the original so called
   ``semantic'' parser.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output.  */
#define YYBISON 1

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 1

/* Using locations.  */
#define YYLSP_NEEDED 0



/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     EVAL_INT = 258,
     EVAL_GPR = 259,
     EVAL_FPR = 260,
     EVAL_REG_PC = 261,
     EVAL_REG_CR = 262,
     EVAL_REG_LR = 263,
     EVAL_REG_CTR = 264,
     EVAL_REG_XER = 265,
     EVAL_REG_MSR = 266,
     EVAL_REG_SRR0 = 267,
     EVAL_REG_SRR1 = 268,
     EVAL_STR = 269,
     EVAL_FLOAT = 270,
     EVAL_IDENT = 271,
     EVAL_PRINT = 272,
     EVAL_SETREG = 273,
     EVAL_REGS = 274,
     EVAL_FLOATS = 275,
     EVAL_BREAK = 276,
     EVAL_LIST_BREAK = 277,
     EVAL_STEP = 278,
     EVAL_NEXT = 279,
     EVAL_CONTINUE = 280,
     EVAL_QUIT = 281,
     EVAL_E2P = 282,
     EVAL_INSPECT_BYTE = 283,
     EVAL_INSPECT_HALF = 284,
     EVAL_INSPECT_WORD = 285,
     EVAL_INSPECT_DWORD = 286,
     EVAL_INSPECT_STRING = 287,
     EVAL_INSPECT_MEM = 288,
     EVAL_WATCH = 289,
     EVAL_WATCH_BYTE = 290,
     EVAL_WATCH_HALF = 291,
     EVAL_WATCH_WORD = 292,
     EVAL_WATCH_DWORD = 293,
     EVAL_DELETE_WATCH = 294,
     EVAL_DUMP = 295,
     EVAL_DISASM = 296,
     EVAL_HELP = 297,
     EVAL_LAND = 298,
     EVAL_LXOR = 299,
     EVAL_LOR = 300,
     EVAL_EQ = 301,
     EVAL_NE = 302,
     EVAL_LT = 303,
     EVAL_LE = 304,
     EVAL_GT = 305,
     EVAL_GE = 306,
     EVAL_SHL = 307,
     EVAL_SHR = 308,
     NEG = 309,
     EVAL_POW = 310
   };
#endif
#define EVAL_INT 258
#define EVAL_GPR 259
#define EVAL_FPR 260
#define EVAL_REG_PC 261
#define EVAL_REG_CR 262
#define EVAL_REG_LR 263
#define EVAL_REG_CTR 264
#define EVAL_REG_XER 265
#define EVAL_REG_MSR 266
#define EVAL_REG_SRR0 267
#define EVAL_REG_SRR1 268
#define EVAL_STR 269
#define EVAL_FLOAT 270
#define EVAL_IDENT 271
#define EVAL_PRINT 272
#define EVAL_SETREG 273
#define EVAL_REGS 274
#define EVAL_FLOATS 275
#define EVAL_BREAK 276
#define EVAL_LIST_BREAK 277
#define EVAL_STEP 278
#define EVAL_NEXT 279
#define EVAL_CONTINUE 280
#define EVAL_QUIT 281
#define EVAL_E2P 282
#define EVAL_INSPECT_BYTE 283
#define EVAL_INSPECT_HALF 284
#define EVAL_INSPECT_WORD 285
#define EVAL_INSPECT_DWORD 286
#define EVAL_INSPECT_STRING 287
#define EVAL_INSPECT_MEM 288
#define EVAL_WATCH 289
#define EVAL_WATCH_BYTE 290
#define EVAL_WATCH_HALF 291
#define EVAL_WATCH_WORD 292
#define EVAL_WATCH_DWORD 293
#define EVAL_DELETE_WATCH 294
#define EVAL_DUMP 295
#define EVAL_DISASM 296
#define EVAL_HELP 297
#define EVAL_LAND 298
#define EVAL_LXOR 299
#define EVAL_LOR 300
#define EVAL_EQ 301
#define EVAL_NE 302
#define EVAL_LT 303
#define EVAL_LE 304
#define EVAL_GT 305
#define EVAL_GE 306
#define EVAL_SHL 307
#define EVAL_SHR 308
#define NEG 309
#define EVAL_POW 310




/* Copy the first part of user declarations.  */
#line 4 "debugparse.y"


#define YYPARSE_PARAM resultptr

#include "debugtype.h"
#include "parsehelper.h"

void yyerror (char *s)
{
	set_eval_error(s);
}



/* Enabling traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif

/* Enabling verbose error messages.  */
#ifdef YYERROR_VERBOSE
# undef YYERROR_VERBOSE
# define YYERROR_VERBOSE 1
#else
# define YYERROR_VERBOSE 0
#endif

#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 18 "debugparse.y"
typedef union YYSTYPE {
	struct eval_command command;
	struct eval_scalar scalar;
	eval_commandtype commandtoken;
	char *ident;
	struct eval_scalarlist scalars;
} YYSTYPE;
/* Line 191 of yacc.c.  */
#line 208 "debugparse.c"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif



/* Copy the second part of user declarations.  */


/* Line 214 of yacc.c.  */
#line 220 "debugparse.c"

#if ! defined (yyoverflow) || YYERROR_VERBOSE

# ifndef YYFREE
#  define YYFREE free
# endif
# ifndef YYMALLOC
#  define YYMALLOC malloc
# endif

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   define YYSTACK_ALLOC alloca
#  endif
# else
#  if defined (alloca) || defined (_ALLOCA_H)
#   define YYSTACK_ALLOC alloca
#  else
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's `empty if-body' warning. */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
# else
#  if defined (__STDC__) || defined (__cplusplus)
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   define YYSIZE_T size_t
#  endif
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
# endif
#endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */


#if (! defined (yyoverflow) \
     && (! defined (__cplusplus) \
	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  short int yyss;
  YYSTYPE yyvs;
  };

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
      + YYSTACK_GAP_MAXIMUM)

/* Copy COUNT objects from FROM to TO.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined (__GNUC__) && 1 < __GNUC__
#   define YYCOPY(To, From, Count) \
      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
#  else
#   define YYCOPY(To, From, Count)		\
      do					\
	{					\
	  register YYSIZE_T yyi;		\
	  for (yyi = 0; yyi < (Count); yyi++)	\
	    (To)[yyi] = (From)[yyi];		\
	}					\
      while (0)
#  endif
# endif

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack)					\
    do									\
      {									\
	YYSIZE_T yynewbytes;						\
	YYCOPY (&yyptr->Stack, Stack, yysize);				\
	Stack = &yyptr->Stack;						\
	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
	yyptr += yynewbytes / sizeof (*yyptr);				\
      }									\
    while (0)

#endif

#if defined (__STDC__) || defined (__cplusplus)
   typedef signed char yysigned_char;
#else
   typedef short int yysigned_char;
#endif

/* YYFINAL -- State number of the termination state. */
#define YYFINAL  73
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   486

/* YYNTOKENS -- Number of terminals. */
#define YYNTOKENS  72
/* YYNNTS -- Number of nonterminals. */
#define YYNNTS  10
/* YYNRULES -- Number of rules. */
#define YYNRULES  78
/* YYNRULES -- Number of states. */
#define YYNSTATES  143

/* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
#define YYUNDEFTOK  2
#define YYMAXUTOK   310

#define YYTRANSLATE(YYX) 						\
  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)

/* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
static const unsigned char yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      68,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,    65,    52,     2,
      70,    71,    63,    62,    43,    61,    46,    64,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,    45,     2,
       2,    69,     2,    44,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,    51,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,    50,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    47,    48,
      49,    53,    54,    55,    56,    57,    58,    59,    60,    66,
      67
};

#if YYDEBUG
/* YYPRHS[YYN] -- Index of the first RHS symbol of rule number YYN in
   YYRHS.  */
static const unsigned char yyprhs[] =
{
       0,     0,     3,     5,     8,    11,    14,    16,    18,    23,
      27,    29,    32,    35,    37,    39,    42,    45,    48,    51,
      54,    57,    61,    65,    69,    73,    77,    81,    84,    88,
      92,    95,    96,    98,    99,   102,   104,   106,   108,   110,
     112,   114,   116,   118,   120,   122,   124,   126,   128,   130,
     134,   138,   142,   146,   150,   154,   158,   162,   166,   170,
     174,   178,   182,   186,   190,   194,   198,   202,   206,   210,
     213,   217,   223,   227,   232,   233,   235,   237,   241
};

/* YYRHS -- A `-1'-separated list of the rules' RHS. */
static const yysigned_char yyrhs[] =
{
      73,     0,    -1,    68,    -1,    74,    68,    -1,    78,    68,
      -1,    17,    78,    -1,    19,    -1,    20,    -1,    18,    77,
      69,    78,    -1,    21,    78,    76,    -1,    22,    -1,    23,
      75,    -1,    24,    75,    -1,    25,    -1,    26,    -1,    27,
      78,    -1,    28,    78,    -1,    29,    78,    -1,    30,    78,
      -1,    31,    78,    -1,    32,    78,    -1,    33,    78,    76,
      -1,    34,    78,    76,    -1,    35,    78,    76,    -1,    36,
      78,    76,    -1,    37,    78,    76,    -1,    38,    78,    76,
      -1,    39,    78,    -1,    40,    78,    76,    -1,    41,    75,
      76,    -1,    42,    75,    -1,    -1,    78,    -1,    -1,    43,
      78,    -1,     4,    -1,     5,    -1,     6,    -1,     7,    -1,
       8,    -1,     9,    -1,    10,    -1,    11,    -1,    12,    -1,
      13,    -1,     3,    -1,    77,    -1,    15,    -1,    14,    -1,
      78,    63,    78,    -1,    78,    64,    78,    -1,    78,    65,
      78,    -1,    78,    62,    78,    -1,    78,    61,    78,    -1,
      78,    52,    78,    -1,    78,    50,    78,    -1,    78,    51,
      78,    -1,    78,    67,    78,    -1,    78,    59,    78,    -1,
      78,    60,    78,    -1,    78,    53,    78,    -1,    78,    54,
      78,    -1,    78,    57,    78,    -1,    78,    58,    78,    -1,
      78,    55,    78,    -1,    78,    56,    78,    -1,    78,    47,
      78,    -1,    78,    48,    78,    -1,    78,    49,    78,    -1,
      61,    78,    -1,    70,    78,    71,    -1,    78,    44,    78,
      45,    78,    -1,    78,    46,    78,    -1,    81,    70,    79,
      71,    -1,    -1,    80,    -1,    78,    -1,    80,    43,    80,
      -1,    16,    -1
};

/* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
static const unsigned char yyrline[] =
{
       0,   102,   102,   103,   104,   107,   108,   109,   110,   111,
     112,   113,   114,   115,   116,   117,   118,   119,   120,   121,
     122,   123,   124,   125,   126,   127,   128,   129,   130,   131,
     132,   135,   140,   143,   148,   152,   153,   154,   155,   156,
     157,   158,   159,   160,   161,   164,   165,   166,   167,   168,
     169,   170,   171,   172,   173,   174,   175,   176,   177,   178,
     179,   180,   181,   182,   183,   184,   185,   186,   187,   188,
     189,   190,   191,   192,   199,   205,   208,   209,   217
};
#endif

#if YYDEBUG || YYERROR_VERBOSE
/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals. */
static const char *const yytname[] =
{
  "$end", "error", "$undefined", "EVAL_INT", "EVAL_GPR", "EVAL_FPR",
  "EVAL_REG_PC", "EVAL_REG_CR", "EVAL_REG_LR", "EVAL_REG_CTR",
  "EVAL_REG_XER", "EVAL_REG_MSR", "EVAL_REG_SRR0", "EVAL_REG_SRR1",
  "EVAL_STR", "EVAL_FLOAT", "EVAL_IDENT", "EVAL_PRINT", "EVAL_SETREG",
  "EVAL_REGS", "EVAL_FLOATS", "EVAL_BREAK", "EVAL_LIST_BREAK", "EVAL_STEP",
  "EVAL_NEXT", "EVAL_CONTINUE", "EVAL_QUIT", "EVAL_E2P",
  "EVAL_INSPECT_BYTE", "EVAL_INSPECT_HALF", "EVAL_INSPECT_WORD",
  "EVAL_INSPECT_DWORD", "EVAL_INSPECT_STRING", "EVAL_INSPECT_MEM",
  "EVAL_WATCH", "EVAL_WATCH_BYTE", "EVAL_WATCH_HALF", "EVAL_WATCH_WORD",
  "EVAL_WATCH_DWORD", "EVAL_DELETE_WATCH", "EVAL_DUMP", "EVAL_DISASM",
  "EVAL_HELP", "','", "'?'", "':'", "'.'", "EVAL_LAND", "EVAL_LXOR",
  "EVAL_LOR", "'|'", "'^'", "'&'", "EVAL_EQ", "EVAL_NE", "EVAL_LT",
  "EVAL_LE", "EVAL_GT", "EVAL_GE", "EVAL_SHL", "EVAL_SHR", "'-'", "'+'",
  "'*'", "'/'", "'%'", "NEG", "EVAL_POW", "'\\n'", "'='", "'('", "')'",
  "$accept", "input", "command", "optional_scalar1", "optional_scalar2",
  "reg", "scalar", "scalarlist_or_null", "scalarlist", "identifier", 0
};
#endif

# ifdef YYPRINT
/* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
   token YYLEX-NUM.  */
static const unsigned short int yytoknum[] =
{
       0,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,    44,    63,    58,    46,   298,   299,   300,
     124,    94,    38,   301,   302,   303,   304,   305,   306,   307,
     308,    45,    43,    42,    47,    37,   309,   310,    10,    61,
      40,    41
};
# endif

/* YYR1[YYN] -- Symbol number of symbol that rule YYN derives.  */
static const unsigned char yyr1[] =
{
       0,    72,    73,    73,    73,    74,    74,    74,    74,    74,
      74,    74,    74,    74,    74,    74,    74,    74,    74,    74,
      74,    74,    74,    74,    74,    74,    74,    74,    74,    74,
      74,    75,    75,    76,    76,    77,    77,    77,    77,    77,
      77,    77,    77,    77,    77,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    79,    79,    80,    80,    81
};

/* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
static const unsigned char yyr2[] =
{
       0,     2,     1,     2,     2,     2,     1,     1,     4,     3,
       1,     2,     2,     1,     1,     2,     2,     2,     2,     2,
       2,     3,     3,     3,     3,     3,     3,     2,     3,     3,
       2,     0,     1,     0,     2,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     2,
       3,     5,     3,     4,     0,     1,     1,     3,     1
};

/* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
   STATE-NUM when YYTABLE doesn't specify something else to do.  Zero
   means the default is an error.  */
static const unsigned char yydefact[] =
{
       0,    45,    35,    36,    37,    38,    39,    40,    41,    42,
      43,    44,    48,    47,    78,     0,     0,     6,     7,     0,
      10,    31,    31,    13,    14,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,    31,
      31,     0,     2,     0,     0,     0,    46,     0,     0,     5,
       0,    33,    11,    32,    12,    15,    16,    17,    18,    19,
      20,    33,    33,    33,    33,    33,    33,    27,    33,    33,
      30,    69,     0,     1,     3,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     4,    74,     0,
       0,     9,    21,    22,    23,    24,    25,    26,    28,    29,
      70,     0,    72,    66,    67,    68,    55,    56,    54,    60,
      61,    64,    65,    62,    63,    58,    59,    53,    52,    49,
      50,    51,    57,    76,     0,    75,     8,    34,     0,    73,
       0,    71,    77
};

/* YYDEFGOTO[NTERM-NUM]. */
static const short int yydefgoto[] =
{
      -1,    44,    45,    52,   101,    46,    53,   134,   135,    48
};

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
#define YYPACT_NINF -70
static const short int yypact[] =
{
     138,   -70,   -70,   -70,   -70,   -70,   -70,   -70,   -70,   -70,
     -70,   -70,   -70,   -70,   -70,    -2,   447,   -70,   -70,    -2,
     -70,    -2,    -2,   -70,   -70,    -2,    -2,    -2,    -2,    -2,
      -2,    -2,    -2,    -2,    -2,    -2,    -2,    -2,    -2,    -2,
      -2,    -2,   -70,    -2,    21,   -46,   -70,   163,   -30,   235,
     -45,   189,   -70,   235,   -70,   235,   235,   235,   235,   235,
     235,   189,   189,   189,   189,   189,   189,   235,   189,   -20,
     -70,   -25,    57,   -70,   -70,    -2,    -2,    -2,    -2,    -2,
      -2,    -2,    -2,    -2,    -2,    -2,    -2,    -2,    -2,    -2,
      -2,    -2,    -2,    -2,    -2,    -2,    -2,   -70,    -2,    -2,
      -2,   -70,   -70,   -70,   -70,   -70,   -70,   -70,   -70,   -70,
     -70,   213,   256,   133,   275,   293,   310,   326,   341,   356,
     370,   383,   -12,    72,     2,   402,   419,   -47,   -47,   -25,
     -25,   -25,   -70,   235,   -17,    15,   235,   235,    -2,   -70,
      -2,   235,   -70
};

/* YYPGOTO[NTERM-NUM].  */
static const short int yypgoto[] =
{
     -70,   -70,   -70,    17,   409,    54,     0,   -70,   -69,   -70
};

/* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule which
   number is the opposite.  If zero, do what YYDEFACT says.
   If YYTABLE_NINF, syntax error.  */
#define YYTABLE_NINF -1
static const short int yytable[] =
{
      47,     1,     2,     3,     4,     5,     6,     7,     8,     9,
      10,    11,    12,    13,    14,    49,    93,    94,    95,    51,
      96,    73,    74,   100,    99,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    64,    65,    66,    67,    68,    54,
      98,    71,    96,    72,    -1,    87,    88,    89,    90,    91,
      92,    93,    94,    95,   139,    96,    69,    70,   140,    41,
      -1,    89,    90,    91,    92,    93,    94,    95,    43,    96,
      50,   142,     0,     0,     0,   111,   112,   113,   114,   115,
     116,   117,   118,   119,   120,   121,   122,   123,   124,   125,
     126,   127,   128,   129,   130,   131,   132,     0,   133,   136,
     137,    75,     0,    76,    77,    78,    79,    80,    81,    82,
      83,    84,    85,    86,    87,    88,    89,    90,    91,    92,
      93,    94,    95,     0,    96,     0,     0,     0,   110,    -1,
      88,    89,    90,    91,    92,    93,    94,    95,   141,    96,
     133,     1,     2,     3,     4,     5,     6,     7,     8,     9,
      10,    11,    12,    13,    14,    15,    16,    17,    18,    19,
      20,    21,    22,    23,    24,    25,    26,    27,    28,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    78,    79,    80,    81,    82,    83,    84,    85,    86,
      87,    88,    89,    90,    91,    92,    93,    94,    95,    41,
      96,     0,     0,     0,     0,     0,    42,    75,    43,    76,
      77,    78,    79,    80,    81,    82,    83,    84,    85,    86,
      87,    88,    89,    90,    91,    92,    93,    94,    95,     0,
      96,    97,   100,    75,     0,    76,    77,    78,    79,    80,
      81,    82,    83,    84,    85,    86,    87,    88,    89,    90,
      91,    92,    93,    94,    95,     0,    96,    75,   138,    76,
      77,    78,    79,    80,    81,    82,    83,    84,    85,    86,
      87,    88,    89,    90,    91,    92,    93,    94,    95,    75,
      96,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,     0,    96,    77,    78,    79,    80,    81,    82,    83,
      84,    85,    86,    87,    88,    89,    90,    91,    92,    93,
      94,    95,     0,    96,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,     0,    96,    80,    81,    82,    83,    84,    85,    86,
      87,    88,    89,    90,    91,    92,    93,    94,    95,     0,
      96,    81,    82,    83,    84,    85,    86,    87,    88,    89,
      90,    91,    92,    93,    94,    95,     0,    96,    82,    83,
      84,    85,    86,    87,    88,    89,    90,    91,    92,    93,
      94,    95,     0,    96,    83,    84,    85,    86,    87,    88,
      89,    90,    91,    92,    93,    94,    95,     0,    96,    -1,
      84,    85,    86,    87,    88,    89,    90,    91,    92,    93,
      94,    95,     0,    96,    -1,    85,    86,    87,    88,    89,
      90,    91,    92,    93,    94,    95,     0,    96,    -1,    86,
      87,    88,    89,    90,    91,    92,    93,    94,    95,     0,
      96,     2,     3,     4,     5,     6,     7,     8,     9,    10,
      11,    -1,    90,    91,    92,    93,    94,    95,     0,    96,
     102,   103,   104,   105,   106,   107,     0,   108,   109,    -1,
      91,    92,    93,    94,    95,     0,    96
};

static const short int yycheck[] =
{
       0,     3,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    15,    63,    64,    65,    19,
      67,     0,    68,    43,    69,    25,    26,    27,    28,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    22,
      70,    41,    67,    43,    56,    57,    58,    59,    60,    61,
      62,    63,    64,    65,    71,    67,    39,    40,    43,    61,
      58,    59,    60,    61,    62,    63,    64,    65,    70,    67,
      16,   140,    -1,    -1,    -1,    75,    76,    77,    78,    79,
      80,    81,    82,    83,    84,    85,    86,    87,    88,    89,
      90,    91,    92,    93,    94,    95,    96,    -1,    98,    99,
     100,    44,    -1,    46,    47,    48,    49,    50,    51,    52,
      53,    54,    55,    56,    57,    58,    59,    60,    61,    62,
      63,    64,    65,    -1,    67,    -1,    -1,    -1,    71,    57,
      58,    59,    60,    61,    62,    63,    64,    65,   138,    67,
     140,     3,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    39,    40,    41,
      42,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,    64,    65,    61,
      67,    -1,    -1,    -1,    -1,    -1,    68,    44,    70,    46,
      47,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,    64,    65,    -1,
      67,    68,    43,    44,    -1,    46,    47,    48,    49,    50,
      51,    52,    53,    54,    55,    56,    57,    58,    59,    60,
      61,    62,    63,    64,    65,    -1,    67,    44,    45,    46,
      47,    48,    49,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,    64,    65,    44,
      67,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    -1,    67,    47,    48,    49,    50,    51,    52,    53,
      54,    55,    56,    57,    58,    59,    60,    61,    62,    63,
      64,    65,    -1,    67,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    -1,    67,    50,    51,    52,    53,    54,    55,    56,
      57,    58,    59,    60,    61,    62,    63,    64,    65,    -1,
      67,    51,    52,    53,    54,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    64,    65,    -1,    67,    52,    53,
      54,    55,    56,    57,    58,    59,    60,    61,    62,    63,
      64,    65,    -1,    67,    53,    54,    55,    56,    57,    58,
      59,    60,    61,    62,    63,    64,    65,    -1,    67,    53,
      54,    55,    56,    57,    58,    59,    60,    61,    62,    63,
      64,    65,    -1,    67,    54,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    64,    65,    -1,    67,    55,    56,
      57,    58,    59,    60,    61,    62,    63,    64,    65,    -1,
      67,     4,     5,     6,     7,     8,     9,    10,    11,    12,
      13,    59,    60,    61,    62,    63,    64,    65,    -1,    67,
      61,    62,    63,    64,    65,    66,    -1,    68,    69,    60,
      61,    62,    63,    64,    65,    -1,    67
};

/* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
   symbol of state STATE-NUM.  */
static const unsigned char yystos[] =
{
       0,     3,     4,     5,     6,     7,     8,     9,    10,    11,
      12,    13,    14,    15,    16,    17,    18,    19,    20,    21,
      22,    23,    24,    25,    26,    27,    28,    29,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    39,    40,    41,
      42,    61,    68,    70,    73,    74,    77,    78,    81,    78,
      77,    78,    75,    78,    75,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    75,
      75,    78,    78,     0,    68,    44,    46,    47,    48,    49,
      50,    51,    52,    53,    54,    55,    56,    57,    58,    59,
      60,    61,    62,    63,    64,    65,    67,    68,    70,    69,
      43,    76,    76,    76,    76,    76,    76,    76,    76,    76,
      71,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    78,    78,    78,    78,    78,    78,
      78,    78,    78,    78,    79,    80,    78,    78,    45,    71,
      43,    78,    80
};

#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
# define YYSIZE_T __SIZE_TYPE__
#endif
#if ! defined (YYSIZE_T) && defined (size_t)
# define YYSIZE_T size_t
#endif
#if ! defined (YYSIZE_T)
# if defined (__STDC__) || defined (__cplusplus)
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# endif
#endif
#if ! defined (YYSIZE_T)
# define YYSIZE_T unsigned int
#endif

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		(-2)
#define YYEOF		0

#define YYACCEPT	goto yyacceptlab
#define YYABORT		goto yyabortlab
#define YYERROR		goto yyerrorlab


/* Like YYERROR except do call yyerror.  This remains here temporarily
   to ease the transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */

#define YYFAIL		goto yyerrlab

#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)					\
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    {								\
      yychar = (Token);						\
      yylval = (Value);						\
      yytoken = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { 								\
      yyerror ("syntax error: cannot back up");\
      YYERROR;							\
    }								\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

/* YYLLOC_DEFAULT -- Compute the default location (before the actions
   are run).  */

#ifndef YYLLOC_DEFAULT
# define YYLLOC_DEFAULT(Current, Rhs, N)		\
   ((Current).first_line   = (Rhs)[1].first_line,	\
    (Current).first_column = (Rhs)[1].first_column,	\
    (Current).last_line    = (Rhs)[N].last_line,	\
    (Current).last_column  = (Rhs)[N].last_column)
#endif

/* YYLEX -- calling `yylex' with the right arguments.  */

#ifdef YYLEX_PARAM
# define YYLEX yylex (&yylval, YYLEX_PARAM)
#else
# define YYLEX yylex (&yylval)
#endif

/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)			\
do {						\
  if (yydebug)					\
    YYFPRINTF Args;				\
} while (0)

# define YYDSYMPRINT(Args)			\
do {						\
  if (yydebug)					\
    yysymprint Args;				\
} while (0)

# define YYDSYMPRINTF(Title, Token, Value, Location)		\
do {								\
  if (yydebug)							\
    {								\
      YYFPRINTF (stderr, "%s ", Title);				\
      yysymprint (stderr, 					\
                  Token, Value);	\
      YYFPRINTF (stderr, "\n");					\
    }								\
} while (0)

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_stack_print (short int *bottom, short int *top)
#else
static void
yy_stack_print (bottom, top)
    short int *bottom;
    short int *top;
#endif
{
  YYFPRINTF (stderr, "Stack now");
  for (/* Nothing. */; bottom <= top; ++bottom)
    YYFPRINTF (stderr, " %d", *bottom);
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)				\
do {								\
  if (yydebug)							\
    yy_stack_print ((Bottom), (Top));				\
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yy_reduce_print (int yyrule)
#else
static void
yy_reduce_print (yyrule)
    int yyrule;
#endif
{
  int yyi;
  unsigned int yylno = yyrline[yyrule];
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
             yyrule - 1, yylno);
  /* Print the symbols being reduced, and their result.  */
  for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
}

# define YY_REDUCE_PRINT(Rule)		\
do {					\
  if (yydebug)				\
    yy_reduce_print (Rule);		\
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args)
# define YYDSYMPRINT(Args)
# define YYDSYMPRINTF(Title, Token, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef	YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
# undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif



#if YYERROR_VERBOSE

# ifndef yystrlen
#  if defined (__GLIBC__) && defined (_STRING_H)
#   define yystrlen strlen
#  else
/* Return the length of YYSTR.  */
static YYSIZE_T
#   if defined (__STDC__) || defined (__cplusplus)
yystrlen (const char *yystr)
#   else
yystrlen (yystr)
     const char *yystr;
#   endif
{
  register const char *yys = yystr;

  while (*yys++ != '\0')
    continue;

  return yys - yystr - 1;
}
#  endif
# endif

# ifndef yystpcpy
#  if defined (__GLIBC__) && defined (_STRING_H) && defined (_GNU_SOURCE)
#   define yystpcpy stpcpy
#  else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
#   if defined (__STDC__) || defined (__cplusplus)
yystpcpy (char *yydest, const char *yysrc)
#   else
yystpcpy (yydest, yysrc)
     char *yydest;
     const char *yysrc;
#   endif
{
  register char *yyd = yydest;
  register const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
#  endif
# endif

#endif /* !YYERROR_VERBOSE */



#if YYDEBUG
/*--------------------------------.
| Print this symbol on YYOUTPUT.  |
`--------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yysymprint (FILE *yyoutput, int yytype, YYSTYPE *yyvaluep)
#else
static void
yysymprint (yyoutput, yytype, yyvaluep)
    FILE *yyoutput;
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  if (yytype < YYNTOKENS)
    {
      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
# ifdef YYPRINT
      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
# endif
    }
  else
    YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);

  switch (yytype)
    {
      default:
        break;
    }
  YYFPRINTF (yyoutput, ")");
}

#endif /* ! YYDEBUG */
/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

#if defined (__STDC__) || defined (__cplusplus)
static void
yydestruct (int yytype, YYSTYPE *yyvaluep)
#else
static void
yydestruct (yytype, yyvaluep)
    int yytype;
    YYSTYPE *yyvaluep;
#endif
{
  /* Pacify ``unused variable'' warnings.  */
  (void) yyvaluep;

  switch (yytype)
    {

      default:
        break;
    }
}


/* Prevent warnings from -Wmissing-prototypes.  */

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM);
# else
int yyparse ();
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int yyparse (void);
#else
int yyparse ();
#endif
#endif /* ! YYPARSE_PARAM */






/*----------.
| yyparse.  |
`----------*/

#ifdef YYPARSE_PARAM
# if defined (__STDC__) || defined (__cplusplus)
int yyparse (void *YYPARSE_PARAM)
# else
int yyparse (YYPARSE_PARAM)
  void *YYPARSE_PARAM;
# endif
#else /* ! YYPARSE_PARAM */
#if defined (__STDC__) || defined (__cplusplus)
int
yyparse (void)
#else
int
yyparse ()

#endif
#endif
{
  /* The lookahead symbol.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;

/* Number of syntax errors so far.  */
int yynerrs;

  register int yystate;
  register int yyn;
  int yyresult;
  /* Number of tokens to shift before error messages enabled.  */
  int yyerrstatus;
  /* Lookahead token as an internal (translated) token number.  */
  int yytoken = 0;

  /* Three stacks and their tools:
     `yyss': related to states,
     `yyvs': related to semantic values,
     `yyls': related to locations.

     Refer to the stacks thru separate pointers, to allow yyoverflow
     to reallocate them elsewhere.  */

  /* The state stack.  */
  short int yyssa[YYINITDEPTH];
  short int *yyss = yyssa;
  register short int *yyssp;

  /* The semantic value stack.  */
  YYSTYPE yyvsa[YYINITDEPTH];
  YYSTYPE *yyvs = yyvsa;
  register YYSTYPE *yyvsp;



#define YYPOPSTACK   (yyvsp--, yyssp--)

  YYSIZE_T yystacksize = YYINITDEPTH;

  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;


  /* When reducing, the number of symbols on the RHS of the reduced
     rule.  */
  int yylen;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss;
  yyvsp = yyvs;


  goto yysetstate;

/*------------------------------------------------------------.
| yynewstate -- Push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
 yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed. so pushing a state here evens the stacks.
     */
  yyssp++;

 yysetstate:
  *yyssp = yystate;

  if (yyss + yystacksize - 1 <= yyssp)
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYSIZE_T yysize = yyssp - yyss + 1;

#ifdef yyoverflow
      {
	/* Give user a chance to reallocate the stack. Use copies of
	   these so that the &'s don't force the real ones into
	   memory.  */
	YYSTYPE *yyvs1 = yyvs;
	short int *yyss1 = yyss;


	/* Each stack pointer address is followed by the size of the
	   data in use in that stack, in bytes.  This used to be a
	   conditional around just the two extra args, but that might
	   be undefined if yyoverflow is a macro.  */
	yyoverflow ("parser stack overflow",
		    &yyss1, yysize * sizeof (*yyssp),
		    &yyvs1, yysize * sizeof (*yyvsp),

		    &yystacksize);

	yyss = yyss1;
	yyvs = yyvs1;
      }
#else /* no yyoverflow */
# ifndef YYSTACK_RELOCATE
      goto yyoverflowlab;
# else
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
	goto yyoverflowlab;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
	yystacksize = YYMAXDEPTH;

      {
	short int *yyss1 = yyss;
	union yyalloc *yyptr =
	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
	if (! yyptr)
	  goto yyoverflowlab;
	YYSTACK_RELOCATE (yyss);
	YYSTACK_RELOCATE (yyvs);

#  undef YYSTACK_RELOCATE
	if (yyss1 != yyssa)
	  YYSTACK_FREE (yyss1);
      }
# endif
#endif /* no yyoverflow */

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;


      YYDPRINTF ((stderr, "Stack size increased to %lu\n",
		  (unsigned long int) yystacksize));

      if (yyss + yystacksize - 1 <= yyssp)
	YYABORT;
    }

  YYDPRINTF ((stderr, "Entering state %d\n", yystate));

  goto yybackup;

/*-----------.
| yybackup.  |
`-----------*/
yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYPACT_NINF)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token: "));
      yychar = YYLEX;
    }

  if (yychar <= YYEOF)
    {
      yychar = yytoken = YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yyn == 0 || yyn == YYTABLE_NINF)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */
  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;


  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  yystate = yyn;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- Do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     `$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
        case 2:
#line 102 "debugparse.y"
    { create_command((struct eval_command*)resultptr, COMMAND_NOP, 0); }
    break;

  case 3:
#line 103 "debugparse.y"
    { *(struct eval_command*)resultptr = yyvsp[-1].command; }
    break;

  case 4:
#line 104 "debugparse.y"
    { create_command((struct eval_command*)resultptr, COMMAND_PRINT, 1, &yyvsp[-1].scalar); }
    break;

  case 5:
#line 107 "debugparse.y"
    { create_command(&yyval.command, COMMAND_PRINT, 1, &yyvsp[0].scalar); }
    break;

  case 6:
#line 108 "debugparse.y"
    { create_command(&yyval.command, COMMAND_REGS, 0); }
    break;

  case 7:
#line 109 "debugparse.y"
    { create_command(&yyval.command, COMMAND_FLOATS, 0); }
    break;

  case 8:
#line 110 "debugparse.y"
    { create_command(&yyval.command, COMMAND_SETREG, 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 9:
#line 111 "debugparse.y"
    { create_command(&yyval.command, COMMAND_BREAK, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 10:
#line 112 "debugparse.y"
    { create_command(&yyval.command, COMMAND_LIST_BREAK, 0); }
    break;

  case 11:
#line 113 "debugparse.y"
    { create_command(&yyval.command, COMMAND_STEP, 1, &yyvsp[0].scalar); }
    break;

  case 12:
#line 114 "debugparse.y"
    { create_command(&yyval.command, COMMAND_NEXT, 1, &yyvsp[0].scalar); }
    break;

  case 13:
#line 115 "debugparse.y"
    { create_command(&yyval.command, COMMAND_CONTINUE, 0); }
    break;

  case 14:
#line 116 "debugparse.y"
    { create_command(&yyval.command, COMMAND_QUIT, 0); }
    break;

  case 15:
#line 117 "debugparse.y"
    { create_command(&yyval.command, COMMAND_E2P, 1, &yyvsp[0].scalar); }
    break;

  case 16:
#line 118 "debugparse.y"
    { create_command(&yyval.command, COMMAND_INSPECT_BYTE, 1, &yyvsp[0].scalar); }
    break;

  case 17:
#line 119 "debugparse.y"
    { create_command(&yyval.command, COMMAND_INSPECT_HALF, 1, &yyvsp[0].scalar); }
    break;

  case 18:
#line 120 "debugparse.y"
    { create_command(&yyval.command, COMMAND_INSPECT_WORD, 1, &yyvsp[0].scalar); }
    break;

  case 19:
#line 121 "debugparse.y"
    { create_command(&yyval.command, COMMAND_INSPECT_DWORD, 1, &yyvsp[0].scalar); }
    break;

  case 20:
#line 122 "debugparse.y"
    { create_command(&yyval.command, COMMAND_INSPECT_STRING, 1, &yyvsp[0].scalar); }
    break;

  case 21:
#line 123 "debugparse.y"
    { create_command(&yyval.command, COMMAND_INSPECT_MEM, 1, &yyvsp[-1].scalar); }
    break;

  case 22:
#line 124 "debugparse.y"
    { create_command(&yyval.command, COMMAND_WATCH, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 23:
#line 125 "debugparse.y"
    { create_command(&yyval.command, COMMAND_WATCH_BYTE, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 24:
#line 126 "debugparse.y"
    { create_command(&yyval.command, COMMAND_WATCH_HALF, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 25:
#line 127 "debugparse.y"
    { create_command(&yyval.command, COMMAND_WATCH_WORD, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 26:
#line 128 "debugparse.y"
    { create_command(&yyval.command, COMMAND_WATCH_DWORD, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 27:
#line 129 "debugparse.y"
    { create_command(&yyval.command, COMMAND_DELETE_WATCH, 1, &yyvsp[0].scalar); }
    break;

  case 28:
#line 130 "debugparse.y"
    { create_command(&yyval.command, COMMAND_DUMP, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 29:
#line 131 "debugparse.y"
    { create_command(&yyval.command, COMMAND_DISASM, 2, &yyvsp[-1].scalar, &yyvsp[0].scalar); }
    break;

  case 30:
#line 132 "debugparse.y"
    { create_command(&yyval.command, COMMAND_HELP, 0); }
    break;

  case 31:
#line 135 "debugparse.y"
    {
						struct eval_scalar s;
						s.type = SCALAR_EMPTY;
						yyval.scalar = s;
					}
    break;

  case 32:
#line 140 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 33:
#line 143 "debugparse.y"
    {
						struct eval_scalar s;
						s.type = SCALAR_EMPTY;
						yyval.scalar = s;
					}
    break;

  case 34:
#line 148 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 35:
#line 152 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 36:
#line 153 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 37:
#line 154 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 38:
#line 155 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 39:
#line 156 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 40:
#line 157 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 41:
#line 158 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 42:
#line 159 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 43:
#line 160 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 44:
#line 161 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 45:
#line 164 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 46:
#line 165 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 47:
#line 166 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 48:
#line 167 "debugparse.y"
    { yyval.scalar = yyvsp[0].scalar; }
    break;

  case 49:
#line 168 "debugparse.y"
    { create_func_call(&yyval.scalar, "*",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 50:
#line 169 "debugparse.y"
    { create_func_call(&yyval.scalar, "/",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 51:
#line 170 "debugparse.y"
    { create_func_call(&yyval.scalar, "%",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 52:
#line 171 "debugparse.y"
    { create_func_call(&yyval.scalar, "+",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 53:
#line 172 "debugparse.y"
    { create_func_call(&yyval.scalar, "-",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 54:
#line 173 "debugparse.y"
    { create_func_call(&yyval.scalar, "&",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 55:
#line 174 "debugparse.y"
    { create_func_call(&yyval.scalar, "|",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 56:
#line 175 "debugparse.y"
    { create_func_call(&yyval.scalar, "^",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 57:
#line 176 "debugparse.y"
    { create_func_call(&yyval.scalar, "**", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 58:
#line 177 "debugparse.y"
    { create_func_call(&yyval.scalar, "<<", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 59:
#line 178 "debugparse.y"
    { create_func_call(&yyval.scalar, ">>", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 60:
#line 179 "debugparse.y"
    { create_func_call(&yyval.scalar, "==", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 61:
#line 180 "debugparse.y"
    { create_func_call(&yyval.scalar, "!=", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 62:
#line 181 "debugparse.y"
    { create_func_call(&yyval.scalar, ">",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 63:
#line 182 "debugparse.y"
    { create_func_call(&yyval.scalar, ">=", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 64:
#line 183 "debugparse.y"
    { create_func_call(&yyval.scalar, "<",  2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 65:
#line 184 "debugparse.y"
    { create_func_call(&yyval.scalar, "<=", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 66:
#line 185 "debugparse.y"
    { create_func_call(&yyval.scalar, "&&", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 67:
#line 186 "debugparse.y"
    { create_func_call(&yyval.scalar, "||", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 68:
#line 187 "debugparse.y"
    { create_func_call(&yyval.scalar, "^^", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 69:
#line 188 "debugparse.y"
    { create_func_call(&yyval.scalar, "-",  1, &yyvsp[0].scalar); }
    break;

  case 70:
#line 189 "debugparse.y"
    { yyval.scalar = yyvsp[-1].scalar; }
    break;

  case 71:
#line 190 "debugparse.y"
    { create_func_call(&yyval.scalar, "?:", 3, &yyvsp[-4].scalar, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 72:
#line 191 "debugparse.y"
    { create_func_call(&yyval.scalar, ".", 2, &yyvsp[-2].scalar, &yyvsp[0].scalar); }
    break;

  case 73:
#line 193 "debugparse.y"
    {	create_func_call_list(&yyval.scalar, yyvsp[-3].ident, &yyvsp[-1].scalars); }
    break;

  case 74:
#line 199 "debugparse.y"
    {
			struct eval_scalarlist s;
			s.count = 0;
			s.scalars = NULL;
			yyval.scalars = s;
		}
    break;

  case 75:
#line 205 "debugparse.y"
    { yyval.scalars = yyvsp[0].scalars; }
    break;

  case 76:
#line 208 "debugparse.y"
    { scalarlist_set(&yyval.scalars, &yyvsp[0].scalar); }
    break;

  case 77:
#line 210 "debugparse.y"
    {
			scalarlist_concat(&yyval.scalars, &yyvsp[-2].scalars, &yyvsp[0].scalars);
			scalarlist_destroy_flat(&yyvsp[-2].scalars);
			scalarlist_destroy_flat(&yyvsp[0].scalars);
		}
    break;

  case 78:
#line 217 "debugparse.y"
    { yyval.ident = yyvsp[0].ident; }
    break;


    }

/* Line 1010 of yacc.c.  */
#line 1708 "debugparse.c"

  yyvsp -= yylen;
  yyssp -= yylen;


  YY_STACK_PRINT (yyss, yyssp);

  *++yyvsp = yyval;


  /* Now `shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTOKENS];

  goto yynewstate;


/*------------------------------------.
| yyerrlab -- here on detecting error |
`------------------------------------*/
yyerrlab:
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
#if YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (YYPACT_NINF < yyn && yyn < YYLAST)
	{
	  YYSIZE_T yysize = 0;
	  int yytype = YYTRANSLATE (yychar);
	  const char* yyprefix;
	  char *yymsg;
	  int yyx;

	  /* Start YYX at -YYN if negative to avoid negative indexes in
	     YYCHECK.  */
	  int yyxbegin = yyn < 0 ? -yyn : 0;

	  /* Stay within bounds of both yycheck and yytname.  */
	  int yychecklim = YYLAST - yyn;
	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
	  int yycount = 0;

	  yyprefix = ", expecting ";
	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
	      {
		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
		yycount += 1;
		if (yycount == 5)
		  {
		    yysize = 0;
		    break;
		  }
	      }
	  yysize += (sizeof ("syntax error, unexpected ")
		     + yystrlen (yytname[yytype]));
	  yymsg = (char *) YYSTACK_ALLOC (yysize);
	  if (yymsg != 0)
	    {
	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
	      yyp = yystpcpy (yyp, yytname[yytype]);

	      if (yycount < 5)
		{
		  yyprefix = ", expecting ";
		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
		      {
			yyp = yystpcpy (yyp, yyprefix);
			yyp = yystpcpy (yyp, yytname[yyx]);
			yyprefix = " or ";
		      }
		}
	      yyerror (yymsg);
	      YYSTACK_FREE (yymsg);
	    }
	  else
	    yyerror ("syntax error; also virtual memory exhausted");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror ("syntax error");
    }



  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
	 error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* If at end of input, pop the error token,
	     then the rest of the stack, then return failure.  */
	  if (yychar == YYEOF)
	     for (;;)
	       {
		 YYPOPSTACK;
		 if (yyssp == yyss)
		   YYABORT;
		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
		 yydestruct (yystos[*yyssp], yyvsp);
	       }
        }
      else
	{
	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
	  yydestruct (yytoken, &yylval);
	  yychar = YYEMPTY;

	}
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:

#ifdef __GNUC__
  /* Pacify GCC when the user code never invokes YYERROR and the label
     yyerrorlab therefore never appears in user code.  */
  if (0)
     goto yyerrorlab;
#endif

  yyvsp -= yylen;
  yyssp -= yylen;
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;	/* Each real token shifted decrements this.  */

  for (;;)
    {
      yyn = yypact[yystate];
      if (yyn != YYPACT_NINF)
	{
	  yyn += YYTERROR;
	  if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYTERROR)
	    {
	      yyn = yytable[yyn];
	      if (0 < yyn)
		break;
	    }
	}

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
	YYABORT;

      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
      yydestruct (yystos[yystate], yyvsp);
      YYPOPSTACK;
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  if (yyn == YYFINAL)
    YYACCEPT;

  YYDPRINTF ((stderr, "Shifting error token, "));

  *++yyvsp = yylval;


  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturn;

/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturn;

#ifndef yyoverflow
/*----------------------------------------------.
| yyoverflowlab -- parser overflow comes here.  |
`----------------------------------------------*/
yyoverflowlab:
  yyerror ("parser stack overflow");
  yyresult = 2;
  /* Fall through.  */
#endif

yyreturn:
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  return yyresult;
}


#line 220 "debugparse.y"


